
#include "HardwareProfile.h"
#include "Compiler.h"
#include "GenericTypeDefs.h"
#include "delay.h"


void ADCInit ()
{

        //Set up the ADC
        ADCON2 = 0xaa;  //      bit7: 0 left, 1 right justified (using left)
                                        //      bit6: Unimplemented
                                        //      bit 5-3: ACQT<2:0>: A/D Acquisition time select bits. 101 = 12 TAD
                                        //      bit 2-0: ADCS<2:0>: A/D Conversion Clock Select bits. 
                                        //      Fosc/32
                                        //     
 
        ADCON1 = 0x8;  //      bit 7-4: Unimplemented: Read as 0
                                        //      bit 3-2: PVCFG<1:0>: Positive Voltage Reference select bit. 00 = VDD.
                                        //      bit 1-0: NVCFG<1:0>: Negative Voltage Reference select bit. 00 = VDD.
 
        ANSEL = 0x90;           	//      bit 7 ANS7: RC3 Analog Select Control bit I sw
                                        //      bit 6 ANS6: RC2 Analog Select Control bit
                                        //      bit 5 ANS5: RC1 Analog Select Control bit
                                        //      bit 4 ANS4: RC0 Analog Select Control bit U 400v
                                        //      bit 3 ANS3: RA4 Analog Select Control bit
                                        //      1 = Digital input buffer is disabled
                                        //      0 = Digital input buffer is enabled
                                        //      bit 2-0 Unimplemented: Rad as 0
                                        //      00001000 = 0x08
 
        ANSELH = 0x08;          //      bit 7-4 Unimplemented: Read as 0
                                        //      bit 3 ANS11: RB5 Analog Select Control bit  switch
                                        //      bit 2 ANS10: RB4 Analog Select Control bit
                                        //      bit 1 ANS9: RC7 Analog Select Control bit
                                        //      bit 0 ANS8: RC6 Analog Select Control bit
 
        ADCON0 = 0x11;  //      bit 7-6 Unimplemented: Read as 0
                                        //      bit 5-2 CHS<3:0>: Analog Channel Select bits. 0100 = AN4
                                        //      bit 1 GO/DONE: A/D Conversion Status bit. 0 initially
                                        //      bit 0 ADON: ADC Enable bit. 1 = ADC is enabled
                                        //      00001101 = 0x0D
										
										// 		00010001

		REFCON0 = 0xa0;	//FVR = 2,408V
}

WORD ADCGet()
{
              
	WORD_VAL temp;
        ADCON0 = 0x11; //Sel = AN4
	ADCON0bits.GO = 1;                //start conversion
        while(ADCON0bits.GO == 1);
	temp.byte.LB = ADRESL;
	temp.byte.HB = ADRESH;
	temp.Val = (temp.Val * 56) >> 6;
	return temp.Val;
}

WORD ADCGetSwitch()
{
    	WORD_VAL temp;
        ADCON0 = 0x2d; //Sel = AN11
	ADCON0bits.GO = 1;                //start conversion
        while(ADCON0bits.GO == 1);
	temp.byte.LB = ADRESL;
	temp.byte.HB = ADRESH;
//	temp.Val = (temp.Val * 56) >> 6;
	return temp.Val;

}